==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/CollectionSelectorField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/fragment-configuration-fields/CollectionSelectorField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/CollectionSelector', '../../../prop-types/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.CollectionSelectorField = void 0;

    var _form = _interopRequireDefault(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _CollectionSelector = _interopRequireDefault(require("../../../common/components/CollectionSelector"));

    var _index = require("../../../prop-types/index");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    var CollectionSelectorField = function CollectionSelectorField(_ref) {
      var field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          value = _ref.value;
      var _field$typeOptions = field.typeOptions,
          typeOptions = _field$typeOptions === void 0 ? {} : _field$typeOptions;
      return _react["default"].createElement(_form["default"].Group, {
        small: true
      }, _react["default"].createElement(_CollectionSelector["default"], {
        collectionTitle: value.title,
        itemSelectorURL: typeOptions.infoListSelectorURL,
        label: field.label,
        onCollectionSelect: function onCollectionSelect(collection) {
          onValueSelect(field.name, collection);
        }
      }));
    };

    exports.CollectionSelectorField = CollectionSelectorField;
    //# sourceMappingURL=CollectionSelectorField.js.map
  }
});
//# sourceMappingURL=CollectionSelectorField.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/fragment-configuration-fields/CollectionSelectorField.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/fragment-configuration-fields/CollectionSelectorField", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/form', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../common/components/CollectionSelector', '../../../prop-types/index'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.CollectionSelectorField = void 0;

    var _form = _interopRequireDefault(require("@frontend-taglib-clay$clayui/form"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _CollectionSelector = _interopRequireDefault(require("../../../common/components/CollectionSelector"));

    var _index = require("../../../prop-types/index");

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * This library is free software; you can redistribute it and/or modify it under
     * the terms of the GNU Lesser General Public License as published by the Free
     * Software Foundation; either version 2.1 of the License, or (at your option)
     * any later version.
     *
     * This library is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
     * details.
     */
    var CollectionSelectorField = function CollectionSelectorField(_ref) {
      var field = _ref.field,
          onValueSelect = _ref.onValueSelect,
          value = _ref.value;
      var _field$typeOptions = field.typeOptions,
          typeOptions = _field$typeOptions === void 0 ? {} : _field$typeOptions;
      return (/*#__PURE__*/_react.default.createElement(_form.default.Group, {
          small: true
        }, /*#__PURE__*/_react.default.createElement(_CollectionSelector.default, {
          collectionTitle: value.title,
          itemSelectorURL: typeOptions.infoListSelectorURL,
          label: field.label,
          onCollectionSelect: function onCollectionSelect(collection) {
            onValueSelect(field.name, collection);
          }
        }))
      );
    };

    exports.CollectionSelectorField = CollectionSelectorField;
    //# sourceMappingURL=CollectionSelectorField.js.map
  }
});
//# sourceMappingURL=CollectionSelectorField.js.map
